@@ -6,11 +6,11 @@ use Exporter 'import';
 our @EXPORT = qw( test_config );
 
 sub test_config () {
-    (
+    +{
         view => {
-            path => [ 't/nephia-test_app/view' ],
+            include_path => [ 't/nephia-test_app/view' ],
         },
-    );
+    };
 }
 
 1;
